==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/ManagedFieldsEntryFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ManagedFieldsEntryFluentImpl<A extends io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent<A>{
  public ManagedFieldsEntryFluentImpl() {
  }
  public ManagedFieldsEntryFluentImpl(io.fabric8.kubernetes.api.model.ManagedFieldsEntry instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldsType(instance.getFieldsType()); 
    this.withFieldsV1(instance.getFieldsV1()); 
    this.withManager(instance.getManager()); 
    this.withOperation(instance.getOperation()); 
    this.withTime(instance.getTime()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String fieldsType;
  private io.fabric8.kubernetes.api.model.FieldsV1Builder fieldsV1;
  private java.lang.String manager;
  private java.lang.String operation;
  private java.lang.String time;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getFieldsType() {
    return this.fieldsType;
  }
  public A withFieldsType(java.lang.String fieldsType) {
    this.fieldsType=fieldsType; return (A) this;
  }
  public java.lang.Boolean hasFieldsType() {
    return this.fieldsType != null;
  }
  
  /**
   * Method is deprecated. use withFieldsType instead.
   */
  @java.lang.Deprecated
  public A withNewFieldsType(java.lang.String arg0) {
    return (A)withFieldsType(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildFieldsV1 instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.FieldsV1 getFieldsV1() {
    return this.fieldsV1!=null?this.fieldsV1.build():null;
  }
  public io.fabric8.kubernetes.api.model.FieldsV1 buildFieldsV1() {
    return this.fieldsV1!=null?this.fieldsV1.build():null;
  }
  public A withFieldsV1(io.fabric8.kubernetes.api.model.FieldsV1 fieldsV1) {
    _visitables.get("fieldsV1").remove(this.fieldsV1);
    if (fieldsV1!=null){ this.fieldsV1= new io.fabric8.kubernetes.api.model.FieldsV1Builder(fieldsV1); _visitables.get("fieldsV1").add(this.fieldsV1);} return (A) this;
  }
  public java.lang.Boolean hasFieldsV1() {
    return this.fieldsV1 != null;
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> withNewFieldsV1() {
    return new io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluentImpl.FieldsV1NestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> withNewFieldsV1Like(io.fabric8.kubernetes.api.model.FieldsV1 item) {
    return new io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluentImpl.FieldsV1NestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> editFieldsV1() {
    return withNewFieldsV1Like(getFieldsV1());
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> editOrNewFieldsV1() {
    return withNewFieldsV1Like(getFieldsV1() != null ? getFieldsV1(): new io.fabric8.kubernetes.api.model.FieldsV1Builder().build());
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> editOrNewFieldsV1Like(io.fabric8.kubernetes.api.model.FieldsV1 item) {
    return withNewFieldsV1Like(getFieldsV1() != null ? getFieldsV1(): item);
  }
  public java.lang.String getManager() {
    return this.manager;
  }
  public A withManager(java.lang.String manager) {
    this.manager=manager; return (A) this;
  }
  public java.lang.Boolean hasManager() {
    return this.manager != null;
  }
  
  /**
   * Method is deprecated. use withManager instead.
   */
  @java.lang.Deprecated
  public A withNewManager(java.lang.String arg0) {
    return (A)withManager(new String(arg0));
  }
  public java.lang.String getOperation() {
    return this.operation;
  }
  public A withOperation(java.lang.String operation) {
    this.operation=operation; return (A) this;
  }
  public java.lang.Boolean hasOperation() {
    return this.operation != null;
  }
  
  /**
   * Method is deprecated. use withOperation instead.
   */
  @java.lang.Deprecated
  public A withNewOperation(java.lang.String arg0) {
    return (A)withOperation(new String(arg0));
  }
  public java.lang.String getTime() {
    return this.time;
  }
  public A withTime(java.lang.String time) {
    this.time=time; return (A) this;
  }
  public java.lang.Boolean hasTime() {
    return this.time != null;
  }
  
  /**
   * Method is deprecated. use withTime instead.
   */
  @java.lang.Deprecated
  public A withNewTime(java.lang.String arg0) {
    return (A)withTime(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ManagedFieldsEntryFluentImpl that = (ManagedFieldsEntryFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (fieldsType != null ? !fieldsType.equals(that.fieldsType) :that.fieldsType != null) return false;
    if (fieldsV1 != null ? !fieldsV1.equals(that.fieldsV1) :that.fieldsV1 != null) return false;
    if (manager != null ? !manager.equals(that.manager) :that.manager != null) return false;
    if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
    if (time != null ? !time.equals(that.time) :that.time != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  fieldsType,  fieldsV1,  manager,  operation,  time,  super.hashCode());
  }
  public class FieldsV1NestedImpl<N> extends io.fabric8.kubernetes.api.model.FieldsV1FluentImpl<io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<N>> implements io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FieldsV1NestedImpl(io.fabric8.kubernetes.api.model.FieldsV1 item) {
      this.builder = new io.fabric8.kubernetes.api.model.FieldsV1Builder(this, item);
    }
    FieldsV1NestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.FieldsV1Builder(this);
    }
    io.fabric8.kubernetes.api.model.FieldsV1Builder builder;
    public N and() {
      return (N) ManagedFieldsEntryFluentImpl.this.withFieldsV1(builder.build());
    }
    public N endFieldsV1() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/ManagedFieldsEntryFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ManagedFieldsEntryFluentImpl<A extends io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent<A>{
  public ManagedFieldsEntryFluentImpl() {
  }
  public ManagedFieldsEntryFluentImpl(io.fabric8.kubernetes.api.model.ManagedFieldsEntry instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldsType(instance.getFieldsType()); 
    this.withFieldsV1(instance.getFieldsV1()); 
    this.withManager(instance.getManager()); 
    this.withOperation(instance.getOperation()); 
    this.withSubresource(instance.getSubresource()); 
    this.withTime(instance.getTime()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String fieldsType;
  private io.fabric8.kubernetes.api.model.FieldsV1Builder fieldsV1;
  private java.lang.String manager;
  private java.lang.String operation;
  private java.lang.String subresource;
  private java.lang.String time;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getFieldsType() {
    return this.fieldsType;
  }
  public A withFieldsType(java.lang.String fieldsType) {
    this.fieldsType=fieldsType; return (A) this;
  }
  public java.lang.Boolean hasFieldsType() {
    return this.fieldsType != null;
  }
  
  /**
   * Method is deprecated. use withFieldsType instead.
   */
  @java.lang.Deprecated
  public A withNewFieldsType(java.lang.String arg0) {
    return (A)withFieldsType(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildFieldsV1 instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.FieldsV1 getFieldsV1() {
    return this.fieldsV1!=null?this.fieldsV1.build():null;
  }
  public io.fabric8.kubernetes.api.model.FieldsV1 buildFieldsV1() {
    return this.fieldsV1!=null?this.fieldsV1.build():null;
  }
  public A withFieldsV1(io.fabric8.kubernetes.api.model.FieldsV1 fieldsV1) {
    _visitables.get("fieldsV1").remove(this.fieldsV1);
    if (fieldsV1!=null){ this.fieldsV1= new io.fabric8.kubernetes.api.model.FieldsV1Builder(fieldsV1); _visitables.get("fieldsV1").add(this.fieldsV1);} return (A) this;
  }
  public java.lang.Boolean hasFieldsV1() {
    return this.fieldsV1 != null;
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> withNewFieldsV1() {
    return new io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluentImpl.FieldsV1NestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> withNewFieldsV1Like(io.fabric8.kubernetes.api.model.FieldsV1 item) {
    return new io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluentImpl.FieldsV1NestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> editFieldsV1() {
    return withNewFieldsV1Like(getFieldsV1());
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> editOrNewFieldsV1() {
    return withNewFieldsV1Like(getFieldsV1() != null ? getFieldsV1(): new io.fabric8.kubernetes.api.model.FieldsV1Builder().build());
  }
  public io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<A> editOrNewFieldsV1Like(io.fabric8.kubernetes.api.model.FieldsV1 item) {
    return withNewFieldsV1Like(getFieldsV1() != null ? getFieldsV1(): item);
  }
  public java.lang.String getManager() {
    return this.manager;
  }
  public A withManager(java.lang.String manager) {
    this.manager=manager; return (A) this;
  }
  public java.lang.Boolean hasManager() {
    return this.manager != null;
  }
  
  /**
   * Method is deprecated. use withManager instead.
   */
  @java.lang.Deprecated
  public A withNewManager(java.lang.String arg0) {
    return (A)withManager(new String(arg0));
  }
  public java.lang.String getOperation() {
    return this.operation;
  }
  public A withOperation(java.lang.String operation) {
    this.operation=operation; return (A) this;
  }
  public java.lang.Boolean hasOperation() {
    return this.operation != null;
  }
  
  /**
   * Method is deprecated. use withOperation instead.
   */
  @java.lang.Deprecated
  public A withNewOperation(java.lang.String arg0) {
    return (A)withOperation(new String(arg0));
  }
  public java.lang.String getSubresource() {
    return this.subresource;
  }
  public A withSubresource(java.lang.String subresource) {
    this.subresource=subresource; return (A) this;
  }
  public java.lang.Boolean hasSubresource() {
    return this.subresource != null;
  }
  
  /**
   * Method is deprecated. use withSubresource instead.
   */
  @java.lang.Deprecated
  public A withNewSubresource(java.lang.String arg0) {
    return (A)withSubresource(new String(arg0));
  }
  public java.lang.String getTime() {
    return this.time;
  }
  public A withTime(java.lang.String time) {
    this.time=time; return (A) this;
  }
  public java.lang.Boolean hasTime() {
    return this.time != null;
  }
  
  /**
   * Method is deprecated. use withTime instead.
   */
  @java.lang.Deprecated
  public A withNewTime(java.lang.String arg0) {
    return (A)withTime(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ManagedFieldsEntryFluentImpl that = (ManagedFieldsEntryFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (fieldsType != null ? !fieldsType.equals(that.fieldsType) :that.fieldsType != null) return false;
    if (fieldsV1 != null ? !fieldsV1.equals(that.fieldsV1) :that.fieldsV1 != null) return false;
    if (manager != null ? !manager.equals(that.manager) :that.manager != null) return false;
    if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
    if (subresource != null ? !subresource.equals(that.subresource) :that.subresource != null) return false;
    if (time != null ? !time.equals(that.time) :that.time != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  fieldsType,  fieldsV1,  manager,  operation,  subresource,  time,  super.hashCode());
  }
  public class FieldsV1NestedImpl<N> extends io.fabric8.kubernetes.api.model.FieldsV1FluentImpl<io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<N>> implements io.fabric8.kubernetes.api.model.ManagedFieldsEntryFluent.FieldsV1Nested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FieldsV1NestedImpl(io.fabric8.kubernetes.api.model.FieldsV1 item) {
      this.builder = new io.fabric8.kubernetes.api.model.FieldsV1Builder(this, item);
    }
    FieldsV1NestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.FieldsV1Builder(this);
    }
    io.fabric8.kubernetes.api.model.FieldsV1Builder builder;
    public N and() {
      return (N) ManagedFieldsEntryFluentImpl.this.withFieldsV1(builder.build());
    }
    public N endFieldsV1() {
      return and();
    }
    
  }
  
}
